@@ -96,9 +96,7 @@ AudioManager::AudioManager(QObject *parent)
     }
 }
 
-AudioManager::~AudioManager()
-{
-}
+AudioManager::~AudioManager() = default;
 
 QString AudioManager::backendName(KMediaSession::MediaBackends backend) const
 {
@@ -701,8 +699,15 @@ void AudioManager::checkForPendingSeek()
     qCDebug(kastsAudio) << "Seek pending?" << d->m_pendingSeek;
     qCDebug(kastsAudio) << "Current position" << position;
 
+    // FIXME: the LoadedMedia+PlayingState test is a workaround for a broken
+    // qtmultimedia backend; LoadedMedia should never be allowed in the
+    // PlayingState according to docs.  Remove this when upstream is fixed.
+
     // Check if we're supposed to skip to a new position
-    if (d->m_pendingSeek != -1 && d->m_player.mediaStatus() == KMediaSession::BufferedMedia && d->m_player.duration() > 0) {
+    if (d->m_pendingSeek != -1
+        && (d->m_player.mediaStatus() == KMediaSession::BufferedMedia
+            || (d->m_player.mediaStatus() == KMediaSession::LoadedMedia && d->m_player.playbackState() == KMediaSession::PlayingState))
+        && d->m_player.duration() > 0) {
         if (abs(d->m_pendingSeek - position) > 2000) {
             qCDebug(kastsAudio) << "Position seek still pending to position" << d->m_pendingSeek;
             qCDebug(kastsAudio) << "Current reported position and duration" << d->m_player.position() << d->m_player.duration();
@@ -733,11 +738,8 @@ void AudioManager::updateMetaData()
     if (!d->m_entry->feed()->name().isEmpty()) {
         d->m_player.metaData()->setAlbum(d->m_entry->feed()->name());
     }
-    if (d->m_entry->authors().count() > 0) {
-        QString authors;
-        for (auto &author : d->m_entry->authors())
-            authors.append(author->name());
-        d->m_player.metaData()->setArtist(authors);
+    if (d->m_entry->authors().length() > 0) {
+        d->m_player.metaData()->setArtist(d->m_entry->authors());
     }
     if (!d->m_entry->image().isEmpty()) {
         d->m_player.metaData()->setArtworkUrl(QUrl(d->m_entry->cachedImage()));
