@@ -12,7 +12,6 @@
 
 #include <QList>
 #include <QObject>
-#include <QQmlEngine>
 #include <QString>
 #include <QUrl>
 
@@ -23,7 +22,6 @@ class KMediaSessionPrivate;
 class KMEDIASESSION_EXPORT KMediaSession : public QObject
 {
     Q_OBJECT
-    QML_ELEMENT
 
     Q_PROPERTY(KMediaSession::MediaBackends currentBackend READ currentBackend WRITE setCurrentBackend NOTIFY currentBackendChanged)
     Q_PROPERTY(QList<KMediaSession::MediaBackends> availableBackends READ availableBackends CONSTANT)
@@ -91,7 +89,7 @@ public:
     };
     Q_ENUM(Error)
 
-    explicit KMediaSession(const QString &playerName = QStringLiteral(""), const QString &desktopEntryName = QStringLiteral(""), QObject *parent = nullptr);
+    explicit KMediaSession(const QString &playerName = QLatin1String(""), const QString &desktopEntryName = QLatin1String(""), QObject *parent = nullptr);
     ~KMediaSession();
 
     [[nodiscard]] Q_INVOKABLE QString backendName(KMediaSession::MediaBackends backend) const;
