@@ -19,7 +19,9 @@ QHash<int, QByteArray> AbstractEpisodeModel::roleNames() const
         {IdRole, "id"},
         {ReadRole, "read"},
         {NewRole, "new"},
+        {FavoriteRole, "favorite"},
         {ContentRole, "content"},
         {FeedNameRole, "feedname"},
+        {UpdatedRole, "updated"},
     };
 }
